1. ##

2. ##

3. ##

4. ##

    	Docker steps:

    			install docker

    			start the docker service

    				[xonsh] sudo systemctl start docker; sudo systemctl status docker

    			[ ] create a docker container from an image

    					[ ] start container from an image
    						# [xonsh] docker run -v /path_inside_host:/path_inside_container -it ubuntu /bin/bash

    						docker run -it ubuntu /bin/bash

    					[ ] save container to image archive

    						docker export --output="latest.tar" a25061773ac1

    			[ ] start container from image archive

    				# https://docs.docker.com/engine/reference/commandline/image_import/